summaryrefslogtreecommitdiff
path: root/framework/Web/UI/WebControls/TDataList.php
diff options
context:
space:
mode:
authorxue <>2006-04-12 12:18:24 +0000
committerxue <>2006-04-12 12:18:24 +0000
commit373d8acc503b94ea09823f49e2ab5e395eccc584 (patch)
treeb45dbde451c0a53405aaf9f43ba2dcd6047e044d /framework/Web/UI/WebControls/TDataList.php
parent64cc0b33281efbef56fbd6495f433906eda50636 (diff)
Merge from 3.0 branch till 898.
Diffstat (limited to 'framework/Web/UI/WebControls/TDataList.php')
-rw-r--r--framework/Web/UI/WebControls/TDataList.php5
1 files changed, 3 insertions, 2 deletions
diff --git a/framework/Web/UI/WebControls/TDataList.php b/framework/Web/UI/WebControls/TDataList.php
index f5f4b9fa..695d072a 100644
--- a/framework/Web/UI/WebControls/TDataList.php
+++ b/framework/Web/UI/WebControls/TDataList.php
@@ -627,7 +627,7 @@ class TDataList extends TBaseDataList implements INamingContainer, IRepeatInfoUs
}
/**
* @param string how the list should be displayed, using table or using line breaks (Table, Flow)
*/
public function setRepeatLayout($value)
{
@@ -825,7 +825,8 @@ class TDataList extends TBaseDataList implements INamingContainer, IRepeatInfoUs
public function renderItem($writer,$repeatInfo,$itemType,$index)
{
$item=$this->getItem($itemType,$index);
- if($repeatInfo->getRepeatLayout()==='Table')
+ $layout=$repeatInfo->getRepeatLayout();
+ if($layout==='Table' || $layout==='Raw')
$item->renderContents($writer);
else
$item->renderControl($writer);
@@ -627,7 +627,7 @@ class TDataList extends TBaseDataList implements INamingContainer, IRepeatInfoUs
}
/**
- * @param string how the list should be displayed, using table or using line breaks (Table, Flow)
+ * @param string how the list should be displayed, using table or using line breaks (Table, Flow, Raw)
*/
public function setRepeatLayout($value)